==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/wafv2/kotlin/inputs/RuleGroupRuleStatementLabelMatchStatementArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.wafv2.kotlin.inputs

import com.pulumi.aws.wafv2.inputs.RuleGroupRuleStatementLabelMatchStatementArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property key The string to match against.
 * @property scope Specify whether you want to match using the label name or just the namespace. Valid values are `LABEL` or `NAMESPACE`.
 */
public data class RuleGroupRuleStatementLabelMatchStatementArgs(
    public val key: Output<String>,
    public val scope: Output<String>,
) : ConvertibleToJava<com.pulumi.aws.wafv2.inputs.RuleGroupRuleStatementLabelMatchStatementArgs> {
    override fun toJava(): com.pulumi.aws.wafv2.inputs.RuleGroupRuleStatementLabelMatchStatementArgs =
        com.pulumi.aws.wafv2.inputs.RuleGroupRuleStatementLabelMatchStatementArgs.builder()
            .key(key.applyValue({ args0 -> args0 }))
            .scope(scope.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [RuleGroupRuleStatementLabelMatchStatementArgs].
 */
@PulumiTagMarker
public class RuleGroupRuleStatementLabelMatchStatementArgsBuilder internal constructor() {
    private var key: Output<String>? = null

    private var scope: Output<String>? = null

    /**
     * @param value The string to match against.
     */
    @JvmName("vygdlupqocsabhva")
    public suspend fun key(`value`: Output<String>) {
        this.key = value
    }

    /**
     * @param value Specify whether you want to match using the label name or just the namespace. Valid values are `LABEL` or `NAMESPACE`.
     */
    @JvmName("hajaobptaduoptwh")
    public suspend fun scope(`value`: Output<String>) {
        this.scope = value
    }

    /**
     * @param value The string to match against.
     */
    @JvmName("kumimwksuwihenfh")
    public suspend fun key(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.key = mapped
    }

    /**
     * @param value Specify whether you want to match using the label name or just the namespace. Valid values are `LABEL` or `NAMESPACE`.
     */
    @JvmName("wgkjrykpqgldagap")
    public suspend fun scope(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.scope = mapped
    }

    internal fun build(): RuleGroupRuleStatementLabelMatchStatementArgs =
        RuleGroupRuleStatementLabelMatchStatementArgs(
            key = key ?: throw PulumiNullFieldException("key"),
            scope = scope ?: throw PulumiNullFieldException("scope"),
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/wafv2/kotlin/inputs/RuleGroupRuleStatementLabelMatchStatementArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.wafv2.kotlin.inputs

import com.pulumi.aws.wafv2.inputs.RuleGroupRuleStatementLabelMatchStatementArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property key The string to match against.
 * @property scope Specify whether you want to match using the label name or just the namespace. Valid values are `LABEL` or `NAMESPACE`.
 */
public data class RuleGroupRuleStatementLabelMatchStatementArgs(
    public val key: Output<String>,
    public val scope: Output<String>,
) : ConvertibleToJava<com.pulumi.aws.wafv2.inputs.RuleGroupRuleStatementLabelMatchStatementArgs> {
    override fun toJava(): com.pulumi.aws.wafv2.inputs.RuleGroupRuleStatementLabelMatchStatementArgs =
        com.pulumi.aws.wafv2.inputs.RuleGroupRuleStatementLabelMatchStatementArgs.builder()
            .key(key.applyValue({ args0 -> args0 }))
            .scope(scope.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [RuleGroupRuleStatementLabelMatchStatementArgs].
 */
@PulumiTagMarker
public class RuleGroupRuleStatementLabelMatchStatementArgsBuilder internal constructor() {
    private var key: Output<String>? = null

    private var scope: Output<String>? = null

    /**
     * @param value The string to match against.
     */
    @JvmName("kojoqswpmyhlelop")
    public suspend fun key(`value`: Output<String>) {
        this.key = value
    }

    /**
     * @param value Specify whether you want to match using the label name or just the namespace. Valid values are `LABEL` or `NAMESPACE`.
     */
    @JvmName("kyfxlxkwhyajboqy")
    public suspend fun scope(`value`: Output<String>) {
        this.scope = value
    }

    /**
     * @param value The string to match against.
     */
    @JvmName("kaepebjducaxkisp")
    public suspend fun key(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.key = mapped
    }

    /**
     * @param value Specify whether you want to match using the label name or just the namespace. Valid values are `LABEL` or `NAMESPACE`.
     */
    @JvmName("eohaxnnsjjpuwcvi")
    public suspend fun scope(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.scope = mapped
    }

    internal fun build(): RuleGroupRuleStatementLabelMatchStatementArgs =
        RuleGroupRuleStatementLabelMatchStatementArgs(
            key = key ?: throw PulumiNullFieldException("key"),
            scope = scope ?: throw PulumiNullFieldException("scope"),
        )
}
